<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Capoverso
 */

if ( ! function_exists( 'capoverso_paging_nav' ) ) :
/**
 * Display navigation to next/previous set of posts when applicable.
 */
function capoverso_paging_nav() {
	// Don't print empty markup if there's only one page.
	if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
		return;
	}
	?>
	<nav class="navigation paging-navigation" role="navigation">
		<h1 class="screen-reader-text"><?php _e( 'Posts navigation', 'capoverso' ); ?></h1>
		<div class="nav-links">

			<?php if ( get_next_posts_link() ) : ?>
			<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'capoverso' ) ); ?></div>
			<?php endif; ?>

			<?php if ( get_previous_posts_link() ) : ?>
			<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'capoverso' ) ); ?></div>
			<?php endif; ?>

		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif;

if ( ! function_exists( 'capoverso_post_nav' ) ) :
/**
 * Display navigation to next/previous post when applicable.
 */
function capoverso_post_nav() {
	// Don't print empty markup if there's nowhere to navigate.
	$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );

	if ( ! $next && ! $previous ) {
		return;
	}
	?>
	<nav class="navigation post-navigation" role="navigation">
		<h1 class="screen-reader-text"><?php _e( 'Post navigation', 'capoverso' ); ?></h1>
		<div class="nav-links">
			<?php
				previous_post_link( '<div class="nav-previous">%link</div>', _x( '<span class="meta-nav">&larr;</span>&nbsp;%title', 'Previous post link', 'capoverso' ) );
				next_post_link(     '<div class="nav-next">%link</div>',     _x( '%title&nbsp;<span class="meta-nav">&rarr;</span>', 'Next post link',     'capoverso' ) );
			?>
		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif;

if ( ! function_exists( 'capoverso_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function capoverso_posted_on() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

	$posted_on = '<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>';

	$byline = sprintf(
		_x( 'by %s', 'post author', 'capoverso' ),
		'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
	);

	echo '<span class="byline"> ' . $byline . '</span><span class="posted-on">' . $posted_on . '</span>';

}
endif;

if ( ! function_exists( 'capoverso_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function capoverso_entry_footer() {
	// Hide category and tag text for pages.
	if ( 'post' == get_post_type() ) {

		echo '<div class="categories-and-tags">';

			$categories_list = get_the_category_list( ' ' );
			if ( $categories_list && capoverso_categorized_blog() ) {
				printf( '<span class="cat-links">%1$s</span>', $categories_list );
			}

			the_tags( '<span class="tags-links">', ' ', '</span>' );

			capoverso_post_format();

		echo '</div>';
	}

	if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
		echo '<span class="comments-link">';
		comments_popup_link( __( 'Leave a comment', 'capoverso' ), __( '1 Comment', 'capoverso' ), __( '% Comments', 'capoverso' ) );
		echo '</span>';
	}

	edit_post_link( __( 'Edit', 'capoverso' ), '<span class="edit-link">', '</span>' );
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function capoverso_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'capoverso_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'capoverso_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so capoverso_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so capoverso_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in capoverso_categorized_blog.
 */
function capoverso_category_transient_flusher() {
	// Like, beat it. Dig?
	delete_transient( 'capoverso_categories' );
}
add_action( 'edit_category', 'capoverso_category_transient_flusher' );
add_action( 'save_post',     'capoverso_category_transient_flusher' );


/*
 * Return the post format, linked to the post format archive
 */
function capoverso_post_format() {
	$format  = get_post_format();
	$formats = get_theme_support( 'post-formats' );

	//If the post has no format, or if it's not a format supported by the theme, return
	if ( ! $format || ! has_post_format( $formats[0] ) )
		return;

	printf( '<span class="entry-format"><a href="%1$s" title="%2$s">%3$s</a></span>',
				esc_url( get_post_format_link( $format ) ),
				esc_attr( sprintf( __( 'All %1$s posts', 'capoverso' ), get_post_format_string( $format ) ) ),
				get_post_format_string( $format )
			);
}
